
from django.db import models
from django.utils.translation import ugettext_lazy as _

from turbosms.settings import SMS_DB_TABLE_NAME, SMS_SIGNATURE


class SMS(models.Model):

    number = models.CharField(max_length=21)

    sign = models.CharField(max_length=21, default=SMS_SIGNATURE)

    message = models.TextField(max_length=1530)

    wappush = models.CharField(max_length=128)

    is_flash = models.BooleanField(default=False)

    class Meta:
        db_table = SMS_DB_TABLE_NAME


class SMSRecord(models.Model):

    msg_id = models.CharField(max_length=36)

    number = models.CharField(max_length=21)

    sign = models.CharField(max_length=21, default=SMS_SIGNATURE)

    message = models.TextField(max_length=1530)

    wappush = models.CharField(max_length=128)

    is_flash = models.BooleanField(default=False)

    cost = models.DecimalField(max_digits=4, decimal_places=2)

    balance = models.DecimalField(max_digits=10, decimal_places=2)

    added = models.DateTimeField()

    send_time = models.DateTimeField()

    sended = models.DateTimeField()

    received = models.DateTimeField()

    error_code = models.CharField(max_length=3)

    status = models.CharField(max_length=255)

    class Meta:
        verbose_name = _('SMS record')
        verbose_name_plural = _('SMS Records')
        db_table = SMS_DB_TABLE_NAME




from django.apps import apps
from django.template.loader import render_to_string

from turbosms.settings import IS_SMS_ENABLED, SMS_RECIPIENTS
from turbosms.models import SMS


def get_default_sms_recipients():

    if apps.is_installed('site_config'):
        from site_config import config
        return getattr(config, 'SMS_RECIPIENTS', SMS_RECIPIENTS)

    return SMS_RECIPIENTS


def send_sms(message, recipients=None):

    if not IS_SMS_ENABLED:
        return

    if recipients is None:
        recipients = get_default_sms_recipients()

    for number in recipients:
        SMS.objects.create(number=number, message=message)


def send_sms_from_template(template_name, context=None, recipients=None):
    message = render_to_string(template_name, context)
    send_sms(message, recipients)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-10-26 09:32
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SMS',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('number', models.CharField(max_length=21)),
                ('sign', models.CharField(default=b'InfoNomer', max_length=21)),
                ('message', models.TextField(max_length=1530)),
                ('wappush', models.CharField(max_length=128)),
                ('is_flash', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='SMSRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('msg_id', models.CharField(max_length=36)),
                ('number', models.CharField(max_length=21)),
                ('sign', models.CharField(default=b'InfoNomer', max_length=21)),
                ('message', models.TextField(max_length=1530)),
                ('wappush', models.CharField(max_length=128)),
                ('is_flash', models.BooleanField(default=False)),
                ('cost', models.DecimalField(decimal_places=2, max_digits=4)),
                ('balance', models.DecimalField(decimal_places=2, max_digits=10)),
                ('added', models.DateTimeField()),
                ('send_time', models.DateTimeField()),
                ('sended', models.DateTimeField()),
                ('received', models.DateTimeField()),
                ('error_code', models.CharField(max_length=3)),
                ('status', models.CharField(max_length=255)),
            ],
        ),
    ]




from django.conf import settings


IS_SMS_ENABLED = getattr(settings, 'IS_SMS_ENABLED', False)

SMS_DB_TABLE_NAME = getattr(settings, 'SMS_DB_TABLE_NAME', '')

SMS_RECIPIENTS = getattr(settings, 'SMS_RECIPIENTS', [])

SMS_SIGNATURE = getattr(settings, 'SMS_SIGNATURE', 'Msg')




from django.contrib import admin

from turbosms.models import SMSRecord


class SMSRecordAdmin(admin.ModelAdmin):

    list_display = [
        'number', 'message', 'cost', 'balance', 'msg_id', 'sended', 'status'
    ]
    search_fields = ['number', 'message', 'msg_id']

    def has_add_permission(self, request):
        return False


admin.site.register(SMSRecord, SMSRecordAdmin)




class TurboSMSRouter(object):

    app_label = 'turbosms'
    db_name = 'turbosms'

    def db_for_read(self, model, **hints):

        if model._meta.app_label == self.app_label:
            return self.db_name

        return None

    def db_for_write(self, model, **hints):

        if model._meta.app_label == self.app_label:
            return self.db_name

        return None

    def allow_relation(self, obj1, obj2, **hints):

        if obj1._meta.app_label == self.app_label or \
                obj2._meta.app_label == self.app_label:
            return False

        return None

    def allow_migrate(self, db, app_label, model_name=None, **hints):

        if app_label == self.app_label:
            return False

        return None
